@@ -16,6 +16,13 @@ def output(video_extractor, pretty_print=True):
             out['audiolang'] = ve.audiolang
     except AttributeError:
         pass
+    extra = {}
+    if getattr(ve, 'referer', None) is not None:
+        extra["referer"] = ve.referer
+    if getattr(ve, 'ua', None) is not None:
+        extra["ua"] = ve.ua
+    if extra:
+        out["extra"] = extra
     if pretty_print:
         print(json.dumps(out, indent=4, sort_keys=True, ensure_ascii=False))
     else:
